@@ -32,7 +32,7 @@
 #include <fcntl.h>
 #include <math.h>
 
-// include QT header
+// include TQt header
 #include <tqtimer.h>
 #include <tqdir.h>
 
@@ -59,10 +59,10 @@ HardwareInfo::HardwareInfo() {
 
 	// initialize connection to the TDE hardware library
 	m_hwdevices = TDEGlobal::hardwareDevices();
-	connect(m_hwdevices, TQT_SIGNAL(hardwareUpdated(TDEGenericDevice*)), this, TQT_SLOT(processHardwareChangedEvent(TDEGenericDevice*)));
+	connect(m_hwdevices, TQ_SIGNAL(hardwareUpdated(TDEGenericDevice*)), this, TQ_SLOT(processHardwareChangedEvent(TDEGenericDevice*)));
 
 #ifdef USE_EVENT_DEVICES_DIRECTLY
-	connect(m_hwdevices, TQT_SIGNAL(eventDeviceKeyPressed(unsigned int, TDEEventDevice*)), this, TQT_SLOT(processKeyPressEvent(unsigned int, TDEEventDevice*)));
+	connect(m_hwdevices, TQ_SIGNAL(eventDeviceKeyPressed(unsigned int, TDEEventDevice*)), this, TQ_SLOT(processKeyPressEvent(unsigned int, TDEEventDevice*)));
 #endif
 
 	// update everything the first time
@@ -85,7 +85,7 @@ HardwareInfo::HardwareInfo() {
 	// connect to D-Bus
 	dbus_iface = new dbusInterface();
 	sessionIsActive = dbus_iface->checkActiveSession();
-	connect(dbus_iface, TQT_SIGNAL(activeSessionChanged(bool)), this, TQT_SLOT(handleSessionState(bool)));
+	connect(dbus_iface, TQ_SIGNAL(activeSessionChanged(bool)), this, TQ_SLOT(handleSessionState(bool)));
 
 	checkPowermanagement();
 	checkIsLaptop();
@@ -147,13 +147,13 @@ bool HardwareInfo::reinitHardwareInfos () {
 
 
 /*!
- * \b TQT_SLOT called if the state of the current session change
+ * \b Slot called if the state of the current session change
  * \param state boolean represent the state of the session
  */
 void HardwareInfo::handleSessionState( bool state ) {
     if( state != sessionIsActive ) {
 	sessionIsActive = state;
-	TQTimer::singleShot(50, this, TQT_SLOT(emitSessionActiveState()));
+	TQTimer::singleShot(50, this, TQ_SLOT(emitSessionActiveState()));
     }
 }
 
@@ -166,7 +166,7 @@ void HardwareInfo::processHardwareChangedEvent (TDEGenericDevice* device) {
 
 	if (allUDIs.contains( device->uniqueID() )) {
 		if (device->type() == TDEGenericDeviceType::PowerSupply) {
-			TQTimer::singleShot(50, this, TQT_SLOT(checkACAdapterState()));
+			TQTimer::singleShot(50, this, TQ_SLOT(checkACAdapterState()));
 		} else if (device->type() == TDEGenericDeviceType::Battery) {
 			// this is a battery event
 			updateBatteryValues(device);
@@ -174,11 +174,11 @@ void HardwareInfo::processHardwareChangedEvent (TDEGenericDevice* device) {
 			TDEEventDevice* edevice = dynamic_cast<TDEEventDevice*>(device);
 			if (edevice) {
 				if (edevice->eventType() == TDEEventDeviceType::ACPILidSwitch) {
-					TQTimer::singleShot(50, this, TQT_SLOT(checkLidcloseState()));
+					TQTimer::singleShot(50, this, TQ_SLOT(checkLidcloseState()));
 				}
 			}
 		} else if (device->type() == TDEGenericDeviceType::Backlight) {
-			TQTimer::singleShot(50, this, TQT_SLOT(checkBrightness()));
+			TQTimer::singleShot(50, this, TQ_SLOT(checkBrightness()));
 		}
 		// TODO: add needed code
 	} else {
@@ -201,20 +201,20 @@ void HardwareInfo::processKeyPressEvent(unsigned int keycode, TDEEventDevice* ed
 		kdDebug() << "ButtonPressed event from TDE HW library " << endl;
 		if (((edevice->eventType() == TDEEventDeviceType::ACPIPowerButton) || (edevice->eventType() == TDEEventDeviceType::ACPIOtherInput))
 			&& (keycode == KEY_POWER)) {
-			TQTimer::singleShot(50, this, TQT_SLOT(emitPowerButtonPressed()));
+			TQTimer::singleShot(50, this, TQ_SLOT(emitPowerButtonPressed()));
 		} else if (((edevice->eventType() == TDEEventDeviceType::ACPISuspendButton) || (edevice->eventType() == TDEEventDeviceType::ACPIOtherInput))
 			&& (keycode == KEY_SLEEP)) {
-			TQTimer::singleShot(50, this, TQT_SLOT(emitSuspendButtonPressed()));
+			TQTimer::singleShot(50, this, TQ_SLOT(emitSuspendButtonPressed()));
 		} else if (((edevice->eventType() == TDEEventDeviceType::ACPISuspendButton) || (edevice->eventType() == TDEEventDeviceType::ACPIOtherInput))
 			&& (keycode == KEY_SUSPEND)) {
-			TQTimer::singleShot(50, this, TQT_SLOT(emitS2diskButtonPressed()));
+			TQTimer::singleShot(50, this, TQ_SLOT(emitS2diskButtonPressed()));
 		}
 
 	kdDebugFuncOut(trace);
 }
 
 /*!
- * This TQT_SLOT is used to fetch the resume signal and multiplex. If needed some
+ * This slot is used to fetch the resume signal and multiplex. If needed some
  * actions after resume, do this here.
  * \param result 	integer with the result of the resume/suspend
  */
@@ -605,7 +605,7 @@ bool HardwareInfo::intialiseHWInfo() {
 			if (!allUDIs.contains( hwdevice->uniqueID() )) {
 				allUDIs.append( hwdevice->uniqueID() );
 			}
-			connect(edevice, TQT_SIGNAL(switchChanged()), this, TQT_SLOT(checkLidcloseState()));
+			connect(edevice, TQ_SIGNAL(switchChanged()), this, TQ_SLOT(checkLidcloseState()));
 			checkLidcloseState();
 		}
 	}
@@ -622,7 +622,7 @@ bool HardwareInfo::intialiseHWInfo() {
 	Battery *bat;
 	for (bat = BatteryList.first(); bat; bat = BatteryList.next() ) {
 		if (bat->getType() == BAT_PRIMARY) {
-			connect(bat, TQT_SIGNAL(changedBattery()),this, TQT_SLOT(updatePrimaryBatteries()));
+			connect(bat, TQ_SIGNAL(changedBattery()),this, TQ_SLOT(updatePrimaryBatteries()));
 		}
 	}
 
@@ -631,7 +631,7 @@ bool HardwareInfo::intialiseHWInfo() {
 }
 
 /*!
- * The function/TQT_SLOT checks the state of the AC adapter.
+ * The function/slot checks the state of the AC adapter.
  */
 void HardwareInfo::checkACAdapterState() {
 	kdDebugFuncIn(trace);
@@ -722,10 +722,10 @@ void HardwareInfo::updatePrimaryBatteries () {
 		if (primaryBatteries->getNumBatteries() < 1) {
 			setPrimaryBatteriesWarningLevel();
 			primaryBatteries->refreshInfo( BatteryList );
-			connect(primaryBatteries, TQT_SIGNAL(batteryChanged()), this,
-				TQT_SLOT(setPrimaryBatteriesChanges()));
-			connect(primaryBatteries, TQT_SIGNAL(batteryWarnState(int,int)), this,
-				TQT_SLOT(emitBatteryWARNState(int,int)));
+			connect(primaryBatteries, TQ_SIGNAL(batteryChanged()), this,
+				TQ_SLOT(setPrimaryBatteriesChanges()));
+			connect(primaryBatteries, TQ_SIGNAL(batteryWarnState(int,int)), this,
+				TQ_SLOT(emitBatteryWARNState(int,int)));
 		} else {
 			setPrimaryBatteriesWarningLevel();
 			primaryBatteries->refreshInfo( BatteryList );
