@@ -33,7 +33,7 @@
 #ifndef _HARDWARE_H_
 #define _HARDWARE_H_
 
-// QT - Header
+// TQt - Header
 #include <tqstring.h>
 #include <tqobject.h>
 #include <tqvaluelist.h>
@@ -130,7 +130,7 @@ typedef struct SuspendStates {
 
 class HardwareInfo : public TQObject{
 
-	Q_OBJECT
+	TQ_OBJECT
 
 
 private:
@@ -333,10 +333,10 @@ private slots:
 	//! check if brightness change is possible
 	void checkBrightness();
 
-	//! TQT_SLOT to forward signal about changed battery warning state
+	//! TQ_SLOT to forward signal about changed battery warning state
 	void emitBatteryWARNState (int type, int state);
 
-	//! TQT_SLOT to handle resume and forward a signal for resume
+	//! TQ_SLOT to handle resume and forward a signal for resume
 	void handleResumeSignal (int result);
 
 	//! to emit signal for power button
@@ -348,11 +348,6 @@ private slots:
 	//! to emit signal for session state
 	void emitSessionActiveState();
 
-	//! to handle signal for brightness Up buttons/keys
-	void brightnessUpPressed();
-	//! to handle signal for brightness Down buttons/keys
-	void brightnessDownPressed();
-
 signals:
 	//! signal for larger data changes
 	void generalDataChanged();
@@ -459,8 +454,10 @@ public:
 	// --> functions to call a TDE hardware library and trigger an action
 	//! execute/trigger a suspend via the TDE hardware library
 	bool suspend ( suspend_type suspend );
-	//! set the brightness via TDE hardware library
-	bool setBrightness ( int level, int percent = -1);
+	//! set the brightness level via TDE hardware library
+	bool setBrightnessLevel(int level);
+	//! set the brightness percentage via TDE hardware library
+	bool setBrightnessPercentage(int percent);
 	//! to set the brightness down
 	bool setBrightnessDown(int percentageStep = -1);
 	//! to set the brightness up
